.. image:: /images/eule_small.png
   :alt: a night owl
   :class: with-shadow
   :height: 10ex

.. image:: https://img.shields.io/pypi/v/eule.svg
        :target: https://pypi.python.org/pypi/eule

.. image:: https://codecov.io/gh/quivero/eule/branch/main/graph/badge.svg?token=PJMBaLIqar
        :target: https://codecov.io/gh/quivero/eule

.. image:: https://readthedocs.org/projects/eule/badge/?version=latest
        :target: https://eule.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/brunolnetto/eule/shield.svg
     :target: https://pyup.io/repos/github/brunolnetto/eule/
     :alt: Updates



Euler's diagrams are non-empty Venn's diagrams


* Free software: MIT license
* Documentation: https://eule.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
